SystemOrganization addCategory: #ConfigurationOfDesigner!

Object subclass: #ConfigurationOfDesigner
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDesigner'!

!ConfigurationOfDesigner class methodsFor: 'private' stamp: 'mt 10/28/2010 19:19:07.664'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfDesigner class methodsFor: 'private' stamp: 'mt 10/28/2010 19:19:07.705'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfDesigner class methodsFor: 'metacello tool support' stamp: 'mt 10/28/2010 19:19:07.76'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDesigner class methodsFor: 'metacello tool support' stamp: 'mt 10/28/2010 19:19:07.814'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfDesigner class methodsFor: 'loading' stamp: 'mt 10/28/2010 19:19:07.905'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfDesigner class methodsFor: 'metacello tool support' stamp: 'mt 10/28/2010 19:19:07.867'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfDesigner class methodsFor: 'accessing' stamp: 'mt 10/28/2010 19:19:07.959'!
project

	^self new project! !

!ConfigurationOfDesigner class methodsFor: 'unloading Metacello' stamp: 'mt 10/28/2010 19:19:07.996'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfDesigner methodsFor: 'baselines' stamp: 'mt 10/28/2010 19:34:38.541'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
			
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].

		spec package: 'Designer' with: [spec requires: #('Animations' 'Signals' 'Widgets' 'Icons')].
		spec group: 'default' with: #('Designer')].! !

!ConfigurationOfDesigner methodsFor: 'baselines' stamp: 'mt 10/28/2010 19:39:43.682'!
baseline110: spec 
	<version: '1.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
			
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].

		spec package: 'Designer' with: [spec requires: #('Animations' 'Signals' 'Widgets' 'Icons')].
		spec group: 'default' with: #('Designer')].! !

!ConfigurationOfDesigner methodsFor: 'accessing' stamp: 'mt 10/28/2010 19:19:07.513'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 10/28/2010 19:34:55.195'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec package: 'Widgets' with: 'Widgets-mt.64'.
		spec package: 'Signals' with: 'Signals-mt.27'.
		spec package: 'Animations' with: 'Animations-mt.8'.
		spec package: 'Designer' with: 'Designer-mt.9'.
		spec package: 'Icons' with: 'Icons-mt.1'].! !

!ConfigurationOfDesigner methodsFor: 'versions' stamp: 'mt 10/28/2010 19:39:55.824'!
version110: spec

	<version: '1.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #trunk].! !
